pub enum Numeric {
Int(i32),
Long(i64),
Float(f32),
Double(f64),
}Expand description
A container is needed for these types because many fields are “upgraded” from floats to doubles with new file versions, and other times types may contain multiple inner types
Variants